from typing import List

from PySide2 import QtWidgets


def create_multi_buttons_dialog(
        msg: str, button_labels: List[str], abort_is_0) -> int:
    """
    Create a modal dialog with buttons. Show the dialog and send the user's
    choice to the data object being created.

    :param msg: the instruction shown to the user
    :param button_labels: the list of labels that are shown on the buttons

    :return chosen_idx: index of selected button. If abort_button is selected,
        return 0 if abort_is_0=True or -1 otherwise.
    """
    msg_box = QtWidgets.QMessageBox()
    msg_box.setText(msg)
    buttons = []
    for label in button_labels:
        # RT130's labels have type Tuple[str, int], so we need to convert
        # them to strings.
        if not isinstance(label, str):
            # When we convert a tuple to a string, any strings in the tuple
            # will be surrounded by quotes in the result string. We remove
            # those quotes before displaying them to the user for aesthetic
            # reasons.
            label = str(label).replace("'", '').replace('"', '')
        buttons.append(
            msg_box.addButton(label, QtWidgets.QMessageBox.ActionRole)
        )
    abort_button = msg_box.addButton(QtWidgets.QMessageBox.Abort)

    msg_box.exec_()
    if msg_box.clickedButton() == abort_button:
        if abort_is_0:
            # The default choice is the first item, so we default to it if the
            # user presses the abort button. An alternative choice is to stop
            # when the user presses the abort button.
            chosen_idx = 0
        else:
            chosen_idx = -1
    else:
        chosen_idx = buttons.index(msg_box.clickedButton())
    return chosen_idx
